@@ -44,7 +44,7 @@ $lang = array_merge($lang, array(
 	'DEFAULT_LANGUAGE'				=> 'Standaardtaal',
 	'DEFAULT_STYLE'					=> 'Standaardstijl',
 	'DISABLE_BOARD'					=> 'Forum uitschakelen',
-	'DISABLE_BOARD_EXPLAIN'			=> 'Dit zal het forum onbereikbaar maken voor gebruikers. Als je wilt, kun je ook een kleine boodschap (max. 255 tekens) invoeren.',
+	'DISABLE_BOARD_EXPLAIN'			=> 'Dit zal het forum onbereikbaar maken voor gebruikers die geen beheerder of moderator zijn. Als je wilt, kun je ook een kleine boodschap (max. 255 tekens) invoeren.',
 	'OVERRIDE_STYLE'				=> 'Negeer gebruikersstijl',
 	'OVERRIDE_STYLE_EXPLAIN'		=> 'Negeer de gebruikersstijl door de standaard stijl.',
 	'SITE_DESC'						=> 'Omschrijving van de site',
@@ -104,7 +104,7 @@ $lang = array_merge($lang, array(
 	'AVATAR_GALLERY_PATH'			=> 'Avatar galerijpad',
 	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'Het pad onder je phpBB-rootmap voor standaard afbeeldingen, vb: <samp>images/avatars/gallery</samp>.',
 	'AVATAR_STORAGE_PATH'			=> 'Avatar opslagpad',
-	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Het pad onder je phpBB-rootmap, vb: <samp>images/avatars/upload</samp>.',
+	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Het pad onder je phpBB-rootmap, vb: <samp>images/avatars/upload</samp>.<br />Avatars uploaden <strong>is niet mogelijk</strong> als dit pad niet schrijfbaar is.',
 	'MAX_AVATAR_SIZE'				=> 'Maximale avatargrootte',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'Breedte x hoogte in pixels.',
 	'MAX_FILESIZE'					=> 'Maximale avatarbestandsgrootte',
@@ -547,4 +547,4 @@ $lang = array_merge($lang, array(
 	'JAB_USERNAME_EXPLAIN'		=> 'Geef een geregistreerde gebruikersnaam of een geldig JID op. De gebruikersnaam wordt niet gecontroleerd op correctheid. Als je alleen een gebruikersnaam opgeeft, zal je JID je gebruikersnaam en de server zijn die je hierboven hebt opgegeven. Anders dien je een geldig JID in te vullen, bijvoorbeeld: gebruiker@jabber.org',
 ));
 
-?>
\ No newline at end of file
+?>
