@@ -50,7 +50,7 @@ $lang = array_merge($lang, array(
 	'ACP_BAN'					=> 'Bannen',
 	'ACP_BAN_EMAILS'			=> 'Ban e-mailadres',
 	'ACP_BAN_IPS'				=> 'Ban IP-adres',
-	'ACP_BAN_USERNAMES'			=> 'Ban gebruikersnaam',
+	'ACP_BAN_USERNAMES'			=> 'Ban gebruikers',
 	'ACP_BBCODES'				=> 'BBCodes',
 	'ACP_BOARD_CONFIGURATION'	=> 'Forumconfiguratie',
 	'ACP_BOARD_FEATURES'		=> 'Forumeigenschappen',
@@ -748,4 +748,4 @@ $lang = array_merge($lang, array(
 	'LOG_WORD_EDIT'			=> '<strong>Censuur gewijzigd</strong><br />» %s',
 ));
 
-?>
\ No newline at end of file
+?>
