@@ -88,9 +88,10 @@ $lang = array_merge($lang, array(
 	'AVATAR_PARTIAL_UPLOAD'			=> 'Het geüploade bestand is niet volledig geüpload.',
 	'AVATAR_PHP_SIZE_NA'			=> 'De bestandsgrootte van de avatar is overschreden.<br />De maximale grootte, bepaalt door PHP in php.ini kon niet worden bepaalt.',
 	'AVATAR_PHP_SIZE_OVERRUN'		=> 'De bestandsgrootte van de avatar is overschreden. De maximaal toegestane grootte is %1$d %2$s.<br />Let erop dat dit is ingesteld in het php.ini bestand en kan niet worden overschreven.',
+	'AVATAR_REMOTE_UPLOAD_TIMEOUT'		=> 'De opgegeven avatar kon niet worden geüpload omdat de tijdsduur voor het uploaden is verstreken.',
 	'AVATAR_URL_INVALID'			=> 'De opgegeven URL is ongeldig.',
 	'AVATAR_URL_NOT_FOUND'			=> 'Het opgegeven bestand kon niet worden gevonden.',
-	'AVATAR_WRONG_FILESIZE'			=> 'De bestandsgrootte van de avatar moet tussen 0 en %1d %2s zijn.',
+	'AVATAR_WRONG_FILESIZE'			=> 'De bestandsgrootte van de avatar moet tussen 0 en %1$d %2$s zijn.',
 	'AVATAR_WRONG_SIZE'				=> 'De avatar moet minstens %1$d pixels breed en %2$d pixels hoog zijn. De maximale waardes zijn %3$d pixels breed en %4$d pixels hoog. De opgegeven avatar is %5$d pixels breed en %6$d pixels hoog.',
 
 	'BACK_TO_TOP'			=> 'Omhoog',
@@ -341,6 +342,9 @@ $lang = array_merge($lang, array(
 	'MODERATE'				=> 'Modereer',
 	'MODERATOR'				=> 'Moderator',
 	'MODERATORS'			=> 'Moderators',
+ 	'MODULE_NOT_ACCESS'		=> 'Module niet toegankelijk',
+ 	'MODULE_NOT_FIND'		=> 'Kan de module %s niet vinden',
+ 	'MODULE_FILE_INCORRECT_CLASS'	=> 'Module bestand %s heeft niet de juiste class [%s]',	
 	'MONTH'					=> 'Maand',
 	'MOVE'					=> 'Verplaats',
 	'MSNM'					=> 'WLM',
@@ -653,7 +657,7 @@ $lang = array_merge($lang, array(
 	'TOTAL_USERS_ZERO'	=> 'Totaal aantal leden <strong>0</strong>',
 	'TRACKED_PHP_ERROR'	=> 'Getraceerde PHP-fouten: %s',
 
-	'UNABLE_GET_IMAGE_SIZE'	=> 'De afbeelding kan niet worden geopend, of het is geen geldige afbeelding.',
+	'UNABLE_GET_IMAGE_SIZE'	=> 'De afmetingen van de afbeelding konden niet worden vastgesteld. Controleer of de opgegeven link correct is.',
 	'UNABLE_TO_DELIVER_FILE'=> 'Het bestand kan niet worden afgeleverd.',
 	'UNKNOWN_BROWSER'		=> 'Onbekende browser',
 	'UNMARK_ALL'			=> 'Deselecteer alles',
@@ -897,4 +901,4 @@ $lang = array_merge($lang, array(
 
 ));
 
-?>
\ No newline at end of file
+?>
